@@ -1,3 +1,4 @@
 echo "Installing package dependencies inside docker:"
 echo ""
-python3 -m pyemr.cli_lite python
+pyemr python --env venv
+
