@@ -279,21 +279,6 @@ def get_cluster_name(cluster_name: str = "default"):
 
     Args:
       cluster_name: str:  (Default value = 'default')
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
-      cluster_name: str:  (Default value = "default")
 
     Returns:
 
@@ -345,11 +330,7 @@ def get_project_type(toml_path: str = DEFAULT_TOML_PATH):
 
     Args:
       toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-      toml_path: str:  (Default value = DEFAULT_TOML_PATH)
-
+      
     Returns:
 
     """
@@ -403,14 +384,6 @@ def _write_pyproject_toml(file_contents: dict, pyproj_path: str = DEFAULT_TOML_P
     Args:
       file_contents: dict:
       pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
-      file_contents: dict:
-      pyproj_path: str:  (Default value = DEFAULT_TOML_PATH)
 
     Returns:
 
@@ -552,11 +525,7 @@ def add_dependencies(dependencies: list):
 
     Args:
       dependencies: A list of pypi package names.
-      dependencies: list:
-      dependencies: list:
-      dependencies: list:
-      dependencies: list:
-
+      
     Returns:
 
     """
