@@ -6,6 +6,7 @@ import fire
 from autocorrect import Speller, load_from_tar
 
 from pyemr.utils.config import cprint
+from pyemr.utils.sys import argskwargs_to_argv
 
 
 CUSTOM_VOCAB = {
@@ -168,20 +169,14 @@ def lint_wd(spelling=False, *args, **kwargs):
 
     """
     if not spelling and "S" not in kwargs:
-        args = " ".join(args)
-        kwargs = " ".join([f"-{k} {v}" for k, v in kwargs.items()])
         cmd = [
             "pylint",
             "--ignore",
             "HOWTO.md,README.md,poetry.lock,pyproject.toml,pyemr/files/templates/airflow_spark_step.template.py",
         ]
-        if args:
-            cmd += [args]
-        if kwargs:
-            cmd += [kwargs]
-
+        cmd += argskwargs_to_argv(args, kwargs)
         cmd += ["*"]
-        os.system(" ".join(cmd))
+        os.system(" ".join(cmd).replace("--E", "-E"))
     else:
         cmd = ["pylint"]
         cmd += ["--disable", "all", "--enable", "spelling", "--spelling-dict", "en_US"]
