@@ -1,4 +1,5 @@
 """ """
+import glob
 import os
 import shutil
 import socket
@@ -71,23 +72,24 @@ def os_cmd(*args, **kwargs):
     os.system(cmd)
 
 
-def pexpect_terminate(p):
+def pexpect_terminate(process):
     """
 
     Args:
       p:
+      process:
 
     Returns:
 
     """
-    for i in range(5):
-        if p.isalive():
-            p.sendeof()
-    
+    for _ in range(5):
+        if process.isalive():
+            process.sendeof()
+
     time.sleep(1)
-    if p.isalive():
-        p.terminate()
-    
+    if process.isalive():
+        process.terminate()
+
     return True
 
 
@@ -108,20 +110,21 @@ def pipe_cmd(cmd, cwd=None):
     print("")
     print(f"% {cmd}")
     print("...")
-    print('')
+    print("")
     try:
-        
+
         if cwd:
-            p = pexpect.spawn(cmd, cwd=cwd)
+            process = pexpect.spawn(cmd, cwd=cwd)
         else:
-            p = pexpect.spawn(cmd)
-        
-        p.interact()
+            process = pexpect.spawn(cmd)
+
+        process.interact()
+
     except KeyboardInterrupt:
-        pexpect_terminate(p)
+        pexpect_terminate(process)
         raise
-    
-    pexpect_terminate(p)
+
+    pexpect_terminate(process)
 
 
 def is_port_in_use(port: int):
@@ -132,9 +135,82 @@ def is_port_in_use(port: int):
       port: int:
       port: int:
       port: int:
+      port: int:
 
     Returns:
 
     """
-    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as s:
-        return s.connect_ex(("localhost", port)) == 0
+    with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as soc:
+        return soc.connect_ex(("localhost", port)) == 0
+
+
+def get_all_files(depth=10):
+    """Get all the file paths at some depth. """
+    pattern = "*"
+    for _ in range(depth):
+        for path in glob.glob(pattern):
+            yield path
+        
+        pattern += "/*"
+
+
+
+def search_pwd(pattern):
+    """
+
+    Args:
+      pattern:
+
+    Returns:
+
+    """
+    res = []
+    for path in get_all_files():
+        if os.path.isfile(path):
+            try:
+                with open(path, encoding="utf-8") as file:
+                    if pattern in file.read():
+                        res.append(path)
+            except:
+                pass
+    return res
+
+
+def argskwargs_to_argv(args: list, kwargs: dict):
+    """convert args list and kwargs dict to a list of string.
+
+    Args:
+      args: list:
+      kwargs: dict:
+      args: list:
+      kwargs: dict:
+
+    Returns:
+
+    """
+
+    argv = []
+
+    if args and (len(args) > 0):
+        for arg in args:
+            argv.append(f"{arg}")
+
+    if kwargs and len(kwargs) > 0:
+        for key, value in kwargs.items():
+            argv.append(f"--{key}")
+            argv.append(f"{value}")
+
+    return argv
+
+
+def validate_py_script(script_path):
+    """
+
+    Args:
+      script_path:
+
+    Returns:
+
+    """
+    if not script_path.endswith(".py"):
+        raise ValueError(f"The script '{script_path}' does not end with '.py'")
