@@ -4,54 +4,49 @@ import os
 import sys
 
 from pyemr.utils.mocking import patch_pyspark
-from pyemr.utils.sys import get_site_package_paths, pipe_cmd
+from pyemr.utils.sys import (
+    argskwargs_to_argv, get_site_package_paths, pipe_cmd, validate_py_script,
+)
 
 
 @patch_pyspark
-def test_script_with_s3_mock_sys(script, *args, **kwargs):
+def test_script_with_s3_mock_sys(script, script_args, script_kwargs):
     """
 
     Args:
       script:
-      *args:
-      **kwargs:
+      script_args:
+      script_kwargs:
 
     Returns:
 
     """
+    validate_py_script(script)
     tmp_argv_path = sys.argv.copy()
-
     new_argv = [script]
-    if args:
-        new_argv += args
-
-    for key, value in kwargs.items():
-        new_argv.append(f"--{key}")
-        new_argv.append(value)
-
+    new_argv += argskwargs_to_argv(script_args, script_kwargs)
     sys.argv = new_argv
-
     spec = importlib.util.spec_from_file_location("__main__", script)
     foo = importlib.util.module_from_spec(spec)
     spec.loader.exec_module(foo)
-
     sys.argv = tmp_argv_path
 
 
-def test_script_with_s3_mock_venv(script, *args, **kwargs):
+def test_script_with_s3_mock_venv(script, script_args, script_kwargs):
     """
 
     Args:
       script:
-      *args:
-      **kwargs:
+      script_args:
+      script_kwargs:
 
     Returns:
 
     """
+    validate_py_script(script)
 
     if not os.path.exists("pyproject.toml"):
-        test_script_with_s3_mock_sys(script, *args, **kwargs)
+        test_script_with_s3_mock_sys(script, script_args, script_kwargs)
         return True
     else:
         from pyemr.utils.poetry import install_pyemr_in_poetry_env
@@ -61,34 +56,25 @@ def test_script_with_s3_mock_venv(script, *args, **kwargs):
         site_pkg_paths = get_site_package_paths()
 
         pipe_cmd("poetry install")
-        cmd = ["poetry", "run", "python", "-m", "pyemr.cli_lite", "test", script]
-
-        args = [f"{a}" for a in args]
-        kwargs = [ f"--{k}={v}" for k, v in kwargs.items() ]
-
-        if args:
-            cmd += args
-
-        if kwargs:
-            cmd += kwargs
-
-        cmd += ["--env=sys", f"--additional_site_package_paths={site_pkg_paths}"]
-        cmd = " ".join(cmd)
+        cmd = ["poetry", "run", "python", "-m", "pyemr.cli", "test", script]
+        cmd += argskwargs_to_argv(script_args, script_kwargs)
+        cmd += ["--env", "sys", "--additional_site_package_paths", str(site_pkg_paths)]
         pipe_cmd(cmd)
 
 
-def test_script_with_s3_mock_docker(script, *args, **kwargs):
+def test_script_with_s3_mock_docker(script, script_args, script_kwargs):
     """Test the python script inside the docker container, using s3 mock.
 
     Args:
-      *args:
-      **kwargs:
       script:
+      script_args:
+      script_kwargs:
 
     Returns:
 
     """
     from pyemr.utils.docker import SH_DIR_DOCKER, docker_build_run
 
-    args = " ".join(sys.argv[2:])
-    docker_build_run(f"{SH_DIR_DOCKER}/test_script.sh {args}")
+    argv = argskwargs_to_argv(script_args, script_kwargs)
+    argv = " ".join(argv)
+    docker_build_run(f"{SH_DIR_DOCKER}/test_script.sh {script} {argv}")
