@@ -3,6 +3,7 @@ import shutil
 import time
 import uuid
 from contextlib import contextmanager
+from random import randrange
 
 import pexpect
 import pytest
@@ -144,15 +145,21 @@ def script_dir():
 @pytest.fixture()
 def uid():
     """ """
-    uid = str(uuid.uuid4())[:8]
-    return uid
+    if randrange(2) == 0:
+        uid = randrange(1000000)
+    else:
+        uid = str(uuid.uuid4())[:8]
+    return str(uid)
 
 
 @pytest.fixture(scope="session")
 def sid():
     """ """
-    uid = str(uuid.uuid4())[:8]
-    return uid
+    if randrange(2) == 0:
+        uid = randrange(1000000)
+    else:
+        uid = str(uuid.uuid4())[:8]
+    return str(uid)
 
 
 def _terminate(p):
@@ -169,7 +176,7 @@ def _terminate(p):
         if p.isalive():
             p.sendeof()
             time.sleep(0.5)
-    
+
     time.sleep(1)
     if p.isalive():
         p.terminate()
