@@ -22,7 +22,7 @@ def main(uid, path, stage_dir):
     assert path not in out_path
     print(f"path={path}")
     print(f"path={out_path}")
-    df = sqlContext.read.parquet(path)
+    df = sqlContext.read.parquet(path).limit(10000)
     count = df.count()
     df.limit(100).write.csv(out_path)
     print(f"count={count}")
