@@ -1,7 +1,9 @@
 import glob
 import os
+
 import pytest
 
+
 def test_init(session_tmp_chdir, sid, cluster_name, s3_stage_dir, region):
     """Test initialization method.
 
@@ -75,7 +77,12 @@ def test_build(session_tmp_chdir, pexpect2, sid, s3_stage_dir):
 
 
 def test_testing(
-    session_tmp_chdir, copy_to_session_tmp, pexpect2, sid, s3_stage_dir, s3_parquet_file,
+    session_tmp_chdir,
+    copy_to_session_tmp,
+    pexpect2,
+    sid,
+    s3_stage_dir,
+    s3_parquet_file,
 ):
     """
 
@@ -147,7 +154,7 @@ def test_submitclientmode(
             f"pyemr submit end2end.py client_{sid} {s3_parquet_file} {s3_stage_dir}",
             600,
         ) as ifthen:
-            assert ifthen("DONE.")
+            assert ifthen("COMPLETED")
 
         with pexpect2(f"aws s3 ls {s3_stage_dir}/tmp/client_{sid}/", 120) as ifthen:
             assert ifthen("output.parquet")
@@ -197,7 +204,7 @@ def test_submitclustermode(
             f"pyemr submit end2end.py cluster_{sid} {s3_parquet_file} {s3_stage_dir} --submit_mode cluster",
             600,
         ) as ifthen:
-            assert ifthen("DONE.")
+            assert ifthen("COMPLETED")
 
         with pexpect2(f"aws s3 ls {s3_stage_dir}/tmp/cluster_{sid}/", 120) as ifthen:
             assert ifthen("output.parquet")
@@ -238,10 +245,13 @@ def test_export_airflow(
     if s3_stage_dir and s3_parquet_file and cluster_name and region:
 
         # export script as airflow dag
-        with pexpect2(f"pyemr export end2end.py {sid} {s3_parquet_file} {s3_stage_dir}", 10) as ifthen:
-            ifthen('Schedule Interval','\n')
-            ifthen('correct?','\n')
-        
+        with pexpect2(
+            f"pyemr export end2end.py {sid} {s3_parquet_file} {s3_stage_dir}",
+            10,
+        ) as ifthen:
+            ifthen("Schedule Interval", "\n")
+            ifthen("correct?", "\n")
+
         assert os.path.isfile("airflow_dag.py")
     else:
         pytest.skip(
