@@ -51,7 +51,7 @@ def test_pyemr_add(tmp_chdir, pexpect2, uid):
     toml_path = "./pyproject.toml"
     assert not os.path.isfile(toml_path)
 
-    with pexpect2("pyemr init") as ifthen:
+    with pexpect2("pyemr init", 300) as ifthen:
         ifthen("Project Name", uid)
         ifthen("cluster-name", uid)
         ifthen("s3-staging-dir", f"s3://{uid}")
