@@ -1,9 +1,9 @@
 import os
 
-import pexpect
 import pytest
 from pexpect import EOF
 
+
 def test_pyemr_start_python(tmp_chdir, pexpect2):
     """
 
@@ -17,7 +17,7 @@ def test_pyemr_start_python(tmp_chdir, pexpect2):
     """
     with pexpect2("pyemr python") as ifthen:
         assert ifthen("Select spark_version", "\n")
-        assert ifthen(">>>", 'exit()' )
+        assert ifthen(">>>", "exit()")
 
 
 def test_pyemr_sucess(tmp_chdir, pexpect2, uid):
@@ -38,7 +38,7 @@ def test_pyemr_sucess(tmp_chdir, pexpect2, uid):
     with pexpect2("pyemr python") as ifthen:
         assert ifthen("Select spark_version", "\n")
         assert ifthen(">>>", "\n".join(code))
-        assert ifthen(f"Finished:{uid}",  'exit()' )
+        assert ifthen(f"Finished:{uid}", "exit()")
 
 
 def test_pyemr_fail(pexpect2, uid):
@@ -56,7 +56,7 @@ def test_pyemr_fail(pexpect2, uid):
     with pexpect2("pyemr python") as ifthen:
         assert ifthen("Select spark_version", "\n")
         assert ifthen(">>>", "assert False")
-        assert ifthen("AssertionError",  'exit()' )
+        assert ifthen("AssertionError", "exit()")
 
 
 def test_pyemr_write_dataframe(tmp_chdir, pexpect2, uid, readscript):
@@ -80,7 +80,7 @@ def test_pyemr_write_dataframe(tmp_chdir, pexpect2, uid, readscript):
     with pexpect2("pyemr python") as ifthen:
         assert ifthen("Select spark_version", "\n")
         assert ifthen(">>>", code)
-        assert ifthen(f"Finished:{uid}",  'exit()' )
+        assert ifthen(f"Finished:{uid}", "exit()")
 
     path = out_path.replace("s3:/", "./data/mock/s3")
     assert len(os.listdir(path)) != 0 or os.path.isdir(path)
@@ -110,7 +110,7 @@ def test_read_s3_count_rows(tmp_chdir, pexpect2, uid, readscript, s3_parquet_fil
         with pexpect2("pyemr python") as ifthen:
             assert ifthen("Select spark_version", "\n")
             assert ifthen(">>>", code)
-            assert ifthen(f"Finished:{uid}",  'exit()' )
+            assert ifthen(f"Finished:{uid}", "exit()")
 
         path = s3_parquet_file.replace("s3:/", "./data/mock/s3")
         assert len(os.listdir(path)) != 0 or os.path.isdir(path)
@@ -141,12 +141,12 @@ def test_import_package_script_interactive(tmp_chdir, pexpect2, readscript, uid)
     with pexpect2(cmd, 60) as ifthen:
         assert ifthen(EOF)
 
-    with pexpect2("poetry add cowsay==4.0", 120) as ifthen:
+    with pexpect2("poetry add cowsay==4.0", 300) as ifthen:
         assert ifthen(EOF)
 
     # run import script
     code = f"import sys \nsys.argv = [None, '{uid}'] \n\n"
     code = code + "\n" + readscript("import_package.py") + "\n\n\n"
-    with pexpect2("pyemr python", 600) as ifthen:
+    with pexpect2("pyemr python", 1000) as ifthen:
         assert ifthen(">>>", code)
-        assert ifthen(f"Finished:{uid}",  'exit()' )
+        assert ifthen(f"Finished:{uid}", "exit()")
